function res = armaCOV(ar,ma,sig,n)
% 	ARMACOV   covariance of ARMA process
% 		[RES] = ARMACOV(AR,MA,SIG,N)
% 
% 	Computes the covariances of ARMA model given by
%      y(t) = ar(1).y(t-1) + ... + ar(p).y(t-p)
%                 + e(t) + ma(1).e(t-1) + ... + ma(q).e(t-q)
%   with p = length(ar) and q = length(ma) and
%   e ~ N(0,sig^2)
% 	
% 	Created by Christophe Cahn on 2013-02-16.
% 	Copyright (c)  . All rights reserved.

% formating
ar = reshape(ar,[],1);
ma = reshape(ma,[],1);

% misc
p = length(ar);
q = length(ma);

% trouver les psi_j
psi_j = zeros(n+1,1) ;
if ar == 0
	if n < q
		psi_j = [1;reshape(ma(1:n),[],1)];
	else 
		psi_j(1:q+1) = [1;ma(:)]; 
	end
else	
    psi_j(1) = 1 ;
    for jj=1:n
	    l = min(p,jj);
    	if jj <= q
			psi_j(jj+1) = reshape(ar(1:l),[],1)'*psi_j(jj:-1:jj-l+1) + ma(jj);
		else
			psi_j(jj+1) = reshape(ar(1:l),[],1)'*psi_j(jj:-1:jj-l+1);
		end
    end
end

res = psi_j;

gam_k = zeros(n+1,1);
gam_k(1) = 1;

TET = zeros(n+1);
TET(1,1:q+1) = [1,ma'] ;
for ii=1:q
	TET(ii+1,1:q-ii+1) = ma(ii:q);		
end
PSI = psi_j(:);
rhs = sig^2*TET*PSI ;


PHI = zeros(n+1);
PHI(1,1:p+1) =  [1,-(ar')] ;
for ii=1:p
	PHI(ii+1,1:p-ii+1) = -ar(ii:p);
end
PHI2 = zeros(n+1);
for ii=2:n+1
	PHI2(ii,ii) = 1;
end
for ii=3:n+1
	col1 = max(ii-p,2);
	ncol = ii-col1;
	PHI2(ii,col1:col1+ncol-1) = -ar(ncol:-1:1)';
end

PHI = PHI + PHI2;


tmp = PHI\rhs;

res = [flipud(tmp(2:end));tmp];

