function res = armaDSP(ar,ma,sig,n)
% 	ARMACOV   spectrum of ARMA process
% 		[RES] = ARMADSP(AR,MA,SIG)
% 
% 	Computes the spectrum of ARMA model given by
%      y(t) = ar(1).y(t-1) + ... + ar(p).y(t-p)
%                 + e(t) + ma(1).e(t-1) + ... + ma(q).e(t-q)
%   with p = length(ar) and q = length(ma) and
%   e ~ N(0,sig^2)
% 	
% 	Created by Christophe Cahn on 2013-02-16.
% 	Copyright (c)  . All rights reserved.

if nargin<4
	n =100;
end
w = linspace(0,pi,n)';
% w = [pi./(1:n-1),0]';


p = length(ar);
q = length(ma);

d = max(p,q);

x = zeros(n,d+1);
x(:,1) = ones(n,1);

for ii = 1:d
	x(:,ii+1) = x(:,ii).*exp(i*w);
end

NUM = x(:,1:q+1)*[1;ma(:)];
DEN = x(:,1:p+1)*[1;-ar(:)];
NUM = NUM.*conj(NUM);
DEN = DEN.*conj(DEN);	

res = 1/(2*pi)*sig^2*NUM./DEN;