function res = armaSIM(ar,ma,sig,T,e)
% 	ARMASIM   simulates ARMA model
% 		[RES] = ARMASIM(AR,MA,SIG,T,e)
% 
% 	Simulates an ARMA model given by
%      y(t) = ar(1).y(t-1) + ... + ar(p).y(t-p)
%                 + e(t) + ma(1).e(t-1) + ... + ma(q).e(t-q)
%   with p = length(ar) and q = length(ma) and
%   e ~ N(0,sig^2)
% 	
% 	Created by Christophe Cahn on 2013-02-16.
% 	Copyright (c)  . All rights reserved.

% assume no intercept
p = length(ar) ;
q = length(ma) ;
lagmax = max(p,q) ;

TT = T + lagmax ;

y = zeros(TT,1) ;

if nargin < 5
	e = zeros(TT,1) ;
	e(lagmax+1:TT) = sig*randn(T,1) ;
end

for ii = 1:T
	y(lagmax+ii) = e(lagmax+ii) ;
	for pp = 1:p
		y(lagmax+ii) = y(lagmax+ii) + ar(pp)*y(lagmax+ii-pp) ;
	end
	for qq = 1:q
		y(lagmax+ii) = y(lagmax+ii) + ma(qq)*e(lagmax+ii-qq) ;
	end
end

res = y(lagmax+1:TT);

end %  function