function [irf,sim,dsp,ccv] = bigshow2(ar,ma,sig,Tirf,Tsim,Ncov,Ndsp)
% 	BIGSHOW2   replicates Sargent's bigshow2.m function
% 		
%   [irf,sim,dsp,ccv] = bigshow2(ar,ma,sig,Tirf,Tsim,Ncov,Ndsp)
% 	Plots caracteristics of ARMA model given by
%      y(t) = ar(1).y(t-1) + ... + ar(p).y(t-p)
%                 + e(t) + ma(1).e(t-1) + ... + ma(q).e(t-q)
%   with p = length(ar) and q = length(ma) and
%   e ~ N(0,sig^2)
%
% 	Created by Christophe Cahn on 2013-02-16.
% 	Copyright (c)  . All rights reserved.

if nargin < 7
	Ndsp = 100;
end
if nargin < 6
	Ncov = 15;
end
if nargin < 5
	Tsim = 90;
end
if nargin < 4
	Tirf = 30;
end
if nargin < 3
	sig = 1;
end

irf = armaIRF(ar,ma,sig,Tirf);
sim = armaSIM(ar,ma,sig,Tsim);
dsp = armaDSP(ar,ma,sig,Ndsp);
ccv = armaCOV(ar,ma,sig,Ncov);

subplot(2,2,1); stem(1:Tirf,irf); title('IRF');
subplot(2,2,2); semilogy(linspace(0,pi,Ndsp),dsp); title('spectre');
set(gca,'XTick',[0 , pi/4, pi/2, pi]);
set(gca,'XTickLabel',{'0','pi/4','pi/2','pi'});xlim([0,pi]);ylim([min(dsp),max(dsp)]);
subplot(2,2,3); stem(-Ncov:Ncov,ccv); title('covariogramme'); xlim([-Ncov, Ncov]);
subplot(2,2,4); plot(sim); title('echantillon'); xlim([1,Tsim]);


end %  function