function decis = computeDecisionRule(r,model)
%	Returns the optimal next period asset in a matrix form
%	in rows: assets, in columuns: states 
...
alp = model.params.alp ;
Zed = model.params.Zed ;
dep = model.params.dep ;
phi = model.params.phi ;
gam = model.params.gam ;
mPr = model.params.mPr ;
bet = model.params.bet ;
assetMax = model.params.assetMax ;
nAssets = model.params.nAssets ;
nStates = model.params.nStates ;
vStates = model.params.vStates ;
...
wage = (1-alp)*(Zed*(alp/(r+dep))^alp)^(1/(1-alp));
gridOfAsset = linspace(phi,assetMax,nAssets) ;
cons 	= zeros(nAssets,nAssets,nStates);  
for iState = 1:nStates
	cons(:,:,iState) = vStates(iState)*wage + (1+r)*ones(nAssets,1)*...
						gridOfAsset - gridOfAsset'*ones(1,nAssets);
end
cons(cons<0) = 0 ;
util = (cons.^(1-gam)-1)/(1-gam);

% Initialization
v 		= zeros(nAssets,nStates);
tv		= zeros(nStates,nAssets);
decis   = zeros(nAssets,nStates);
tdecis  = zeros(nStates,nAssets);
vint 	= zeros(nAssets,nAssets,nStates);
isErrorOnDecisonSmall = 0 ;

% Value Function Iteration
while ~isErrorOnDecisonSmall
	for iState = 1:nStates
		futval = sum((ones(nAssets,1)*mPr(iState,:)).*v,2);
		vint(:,:,iState) = util(:,:,iState) + bet*futval*ones(1,nAssets);
		[t1,t2] = max(vint(:,:,iState)) ;
		tv(iState,:) = t1 ;
	 	tdecis(iState,:) = t2 ;
	end
	tv1 = tv' ;
	tdecis1 = tdecis' ;
	isErrorOnDecisonSmall = (max(any(tdecis1-decis)) == 0);
	v=tv1;
	decis=tdecis1;
end;