function [x_max,f_max,iter] = goldsecrule(func,bounds)
%NMM_GOLDSECRULE Golden Section Search
%   NMM_goldsecrule(f,x) help to find the maximizer of a single peacked
%   function f(x) in the interval [x(1),x(2)].
%   see Heer and Maussner (2005) p.468.

%   Copyright 2007 christophe.cahn@pse.ens.fr
...
% Initialization
tol_algo = eps;
A = bounds(1);
D = bounds(2);
p = (sqrt(5)-1)/2;
B = p*A + (1-p)*D;
C = (1-p)*A + p*D;
f_B = func(B);
f_C = func(C);
...
iter = 0;
...
while iter < 1000 && abs(D-A)>tol_algo*max(1,abs(B)+abs(C))
	if f_B == f_C % aie aie aie
		B = (A+B)/2 ;
		C = (C+D)/2 ;
    elseif f_B>f_C
        D = C; C = B; f_C = f_B;
        B = p*C + (1-p)*A;
        f_B = func(B);
    else
        A = B; B = C; f_B = f_C;
        C = p*B+(1-p)*D;
        f_C = func(C);
    end
	iter = iter + 1;
end
if iter == 100
	warning('max iteration has been reached');
end
x_max = A;
f_max = func(x_max);