function [P,Q,flag] = solveLinearDynamicModel(model)
% 	solveLinearDynamicModel   Undetermined coefficient method for solving linear model
% 		[P,Q] = solveLinearDynamicModel(model)
% 		solve the linear dynamic model described by equations:
%			E_t[Fx_{t+1} + Gx_t + Hx_{t-1} + Lz_{t+1} + Mz_t]=0
% 			z_{t+1} = Nz_t + eps_{t+1}
% 		with x_t a (m x 1) vector of endogenous variables and z_t a (k x 1) vector of
%		exogenous variables. 
%		model is a struct that contains fields F, G, H, L, M, and N. 
%

% 	
% 	Created by Christophe on 2009-11-21.
% 	Copyright (c)  __MyCompanyName__. All rights reserved.

flag = 0;

F = model.F ;
G = model.G ;
H = model.H ;
L = model.L ;
M = model.M ;
N = model.N ;

m = model.nEndoVar ;
k = model.nExoVar ;

PHII =  F;
GAMM = -G;
THET = -H;

XII = [GAMM, THET; eye(m), zeros(m)];
DELT = [PHII, zeros(m); zeros(m), eye(m)];

[OMEGAA,LAMBDAA] = eig(XII,DELT);

[ss, idx] = sort(diag(LAMBDAA));

% printf('Eigen values\n\n');
% printf('%f\n', ss);
% printf('\n');

stvalp = idx(abs(ss)<1); 			% select the stable eigen values coordinates 
OMEGAA = OMEGAA(m+1:end,stvalp);	% select OMEGA matrix
LAMBDAA = LAMBDAA(stvalp,stvalp);	% select diagonal matrix

if rcond(OMEGAA)<1e-5
	disp('oups sur OMEGAA')
	pause
end
P = OMEGAA*LAMBDAA*inv(OMEGAA);
V = kron(N',F) + kron(eye(k),F*P+G);
if rcond(V)<eps
	flag = 1;
end
Q = -V\vec(L*N+M);
Q = reshape(Q,m,k);

end %  function