function res = tpy(y,t,country)
% 	TPY   Plots turning points for serie y on sample t
%
% 		res = TPY(y,t) Plots the turning points for the 
%       serie y indexed on the sample t date. The function uses the
%       Harding and Pagan algorithm. 'country' is a string that is
%       used in the plot's title.
%       
%       res is a structure with
%
%             res.PP   : average duration peak to peak
%             res.TT   : average duration trough to trough
%             res.PT   : average duration peak to trough
%             res.TP   : average duration trough to peak
%            res.APT   : average amplitude peak to trough
%            res.ATP   : average amplitude trough to peak
%             res.dP   : dates of peaks
%             res.dT   : dates of troughs
%

% 	Created by Christophe Cahn on 2014-05-02.
% 	Copyright (c)  . All rights reserved.   

k = 2;
T = length(y);
bcp = zeros(T,1);
bct = zeros(T,1);

% étape#1 : identification systématique des pics et des creux

for i = k+1:T-k
    if y(i)>=max(y(i-k:i+k))
        bcp(i)=1;
    end
    if y(i)<=min(y(i-k:i+k))
        bct(i)=1;
    end
end

% on identifie la position des pics et des creux dans y
[I,J] = find([bcp bct]);
X = [I,J];
bcp = X(X(:,2)==1);
bct = X(X(:,2)==2);

% initialisation
nb_pair = 1;

while nb_pair>0 
	% étape#2 : alternance entre pics et creux
	
	% variable J contient le numéro de la colonne, 1 pour un pic
	% 2 pour un creux.
	% on trie selon la première colonne de la matrice X 
	% pour voir s'il y a une alternance
	X = sortrows(X,1);  
	% en faisant la différence sur la deuxième colonne, on identifie
	% les endroits où deux pics ou deux creux se suivent.
	id_alt = diff(X(:,2)); 
	% si au moins un élément nul dans id_alt, il faut choisir
	id_pair = find(id_alt==0);
	nb_pair = length(id_pair);
	elim_X  = zeros(nb_pair,1); 
    for i = 1:nb_pair
        % s'agit-il de deux pics ou deux creux consécutifs ?
        if X(id_pair(i),2) == 1  
	        % 2 pics consecutifs dans les lignes id_pair(i)
	        % et id_pair(i)+1 de X.
            % il s'agit d'un pic, on élimine le plus petit des 2
            % Le premier pic : Y = y(X(id_pair(i),1)),
            % second : Y = y(X(id_pair(i)+1,1))
            if y(X(id_pair(i),1))<y(X(id_pair(i)+1,1))
	            % Le premier pic est plus petit, on elimine la
	            % id_pair(i) eme ligne.
                elim_X(i) = id_pair(i) ;
            else
				% Le premier pic est plus grand, on elimine la 
				% id_pair(i)+1 eme ligne.
                elim_X(i) = id_pair(i)+1 ;
            end
        else      
	        % 2 creux consecutifs dans les lignes id_pair(i) et 
	        % id_pair(i)+1 de X.
            % il s'agit d'un creux, on élimine le plus haut des 2
            % Le premier creux : Y = y(X(id_pair(i),1)), 
            % second : y(X(id_pair(i)+1,1)).
            if y(X(id_pair(i),1))>y(X(id_pair(i)+1,1))   
		        % Le premier creux est plus grand, on elimine la
		        % id_pair(i) eme ligne.
                elim_X(i) = id_pair(i) ;
            else
				% Le premier creux est plus petit, on elimine la
				% id_pair(i)+1 eme ligne.
                elim_X(i) = id_pair(i)+1 ;
            end
        end
    end
    X(elim_X,:)=[];
	bcp = X(X(:,2)==1);
	bct = X(X(:,2)==2);
	
	% étape#3 : Élimination des cycles dont la période complète de
	% reproduction (nombre de périodes séparant un pic d’un 
	% pic ou un creux d’un creux) est inférieure à un temps 
	% minimal imposé a priori (5 pour données trimestrielles)
	t_min = 5;   
 
    % en faisant la différence de bcp et bct, on a le nombre de 
    % périodes entre deux pics ou deux trous
    id_p2p = find(diff(bcp)<t_min);
    id_t2t = find(diff(bct)<t_min);
    nb_short_p2p = length(id_p2p);
    nb_short_t2t = length(id_t2t);    
	elim_bcp  = zeros(nb_short_p2p,1);   
	elim_bct  = zeros(nb_short_t2t,1);
    for i = 1:nb_short_p2p
	   % Le nb de periodes entre le id_p2p(i) eme pic et le 
	   % id_p2p(i)+1 eme est bcp(id_p2p(i)+1)-bcp(id_p2p(i))
       % on élimine le plus petit des 2 pics
       % Le premier pic : Y = y(bcp(id_p2p(i))), 
       % second : Y = y(bcp(id_p2p(i)+1)) 
       if y(bcp(id_p2p(i)))<y(bcp(id_p2p(i)+1))
	        % Le premier pic est plus petit, on elimine le 
	        % id_p2p(i) eme pic.
            elim_bcp(i) = id_p2p(i) ;
        else
	        % Le premier pic est plus grand, on elimine le 
	        % id_p2p(i)+1 eme pic.
            elim_bcp(i) = id_p2p(i)+1 ;
        end
    end  
    for i = 1:nb_short_t2t
	   % Le nb de periodes entre le id_t2t(i) eme trou et le 
	   % id_t2t(i)+1 est bct(id_t2t(i)+1)-bct(id_t2t(i)). 
	   % on élimine le plus grand des 2 trous
       % Le premier trou : Y = y(bct(id_t2t(i))), 
       % second : Y = y(bct(id_t2t(i)+1)) 
       if y(bct(id_t2t(i)))>y(bct(id_t2t(i)+1))
	       % Le premier trou est plus grand, on elimine le 
	       % id_t2t(i) trou.
           elim_bct(i) = id_t2t(i) ;
        else
	       % Le premier trou est plus petit, on elimine le 
	       % id_t2t(i)+1 eme trou.
           elim_bct(i) = id_t2t(i)+1 ;
        end
    end  

    bcp(elim_bcp)=[];           
    bct(elim_bct)=[];       

    % étape 4 : mise en oeuvre des règles complémentaires
    % on teste si le premier évènement est un pic ou un creux
    if bcp(1)<bct(1)
	    if y(bcp(1))<y(1), bcp(1)=[]; end
	else
        if y(bct(1))>y(1), bct(1)=[]; end
	end
	% on teste si le dernier évènement est un pic ou un creux 
	if bcp(end)>bct(end)
        if y(bcp(end))<y(T), bcp(end)=[]; end
	else
	    if y(bct(end))>y(T), bct(end)=[]; end
	end
    if bcp(1)-1<floor(t_min/2), bcp(1)=[]; end
    if bct(1)-1<floor(t_min/2), bct(1)=[]; end
    if T-bcp(end)<floor(t_min/2), bcp(end)=[]; end
	if T-bct(end)<floor(t_min/2), bct(end)=[]; end	
end

% dressage du graphique
figure;
plot(t,y);
ylim = get(gca,'Ylim');    

% Attention, si le premier évènement est un creux,
% on est alors dès le début dans une phase de récession.
bcp_tmp = bcp;
bct_tmp = bct;
if bcp(1)>bct(1), bcp_tmp = [1;bcp]; end
% de même si le dernier évènement est un pic
if bcp(end)>bct(end), bct_tmp = [bct;T]; end
% représentation des phases de récession
n = length(bcp_tmp);
A = [t(1) ylim(1)];
for ii=1:n
	A = [A; t(bcp_tmp(ii)) ylim(1)];
	A = [A; t(bcp_tmp(ii)) ylim(2)];
	A = [A; t(bct_tmp(ii)) ylim(2)];
	A = [A; t(bct_tmp(ii)) ylim(1)];
end

area(A(:,1),A(:,2),ylim(1),'FaceColor',[.9 .9 .9]);
hold on;
plot(t,y,'-',t(bct),y(bct),'kv',t(bcp),y(bcp),'k^');
h = legend('recession','PIB','creux','pics','Location','NorthOutside','Orientation','horizontal'); 
title(country);
set(gca,'Xlim',[t(1) t(end)]);
                            
res.DPP  = mean(diff(bcp));
res.DTT  = mean(diff(bct));
res.DPT  = mean(bct(bct>bcp(1))-bcp(bcp<bct(end)));
res.DTP  = mean(bcp(bcp>bct(1))-bct(bct<bcp(end)));
res.APT = mean(y(bct(bct>bcp(1)))-y(bcp(bcp<bct(end))));
res.ATP = mean(y(bcp(bcp>bct(1)))-y(bct(bct<bcp(end))));  
res.dP = t(bcp);
res.dT = t(bct);                                          
